/** \file main.c
 * \brief Sample STM32F4 project
 * \details This file holds a very basic code for STM32F407VG. This code
 * enables the FPU, all GPIO ports, configures Flash wait-states and enables
 * the PLL to achieve the highest allowed frequency for STM32F407VG (168MHz).
 * Main code block just blinks the LED. The LED port and pin are defined in
 * config.h file. Target core frequency and quartz crystal resonator
 * frequency are defined there as well.
 *
 * \author Freddie Chopin, http://www.freddiechopin.info/
 * \date 2012-03-23
 */

/******************************************************************************
* project: stm32f4_blink_led
* chip: STM32F407VG
* compiler: arm-none-eabi-gcc (GNU Tools for ARM Embedded Processors) 4.6.2
* 	20110921 (release) [ARM/embedded-4_6-branch revision 182083]
*
* prefix: (none)
*
* available global functions:
* 	int main(void)
*
* available local functions:
* 	static void flash_latency(uint32_t frequency)
* 	static void fpu_enable(void)
* 	static uint32_t pll_start(uint32_t crystal, uint32_t frequency)
* 	static void system_init(void)
*
* available interrupt handlers:
******************************************************************************/

/*
+=============================================================================+
| includes
+=============================================================================+
*/

extern "C" {
#include <stdint.h>
#include <inttypes.h>
#include <stdbool.h>

#include "nrf.h"
#include "nrf_delay.h"
#include "nrf_gpio.h"

#include "config.h"
#include "bluetooth.h"
#include "util.h"
}

/*
+=============================================================================+
| module variables
+=============================================================================+
*/

#define BTN_PRESSED 0
#define BTN_RELEASED 1


/*
+=============================================================================+
| local functions' declarations
+=============================================================================+
*/

static void system_init(void);

/*
+=============================================================================+
| global functions
+=============================================================================+
*/

/*------------------------------------------------------------------------*//**
* \brief main code block
* \details Call some static initialization functions and blink the led with
* frequency defined via count_max variable.
*//*-------------------------------------------------------------------------*/

int main(void)
{
    nrf_gpio_cfg_output(led_pin);   // Configure LED-pin as outputs and clear.
    nrf_gpio_pin_clear(led_pin);

	// Setup
	system_init();

	nrf_gpio_pin_set(led_pin);

	BREAK();

	// Main loop
	while(1) {
		power_manage();
	}

	while(1) {
		nrf_gpio_pin_toggle(led_pin);	// toggle LED state
		nrf_delay_ms(500);				// and wait 0.5s
	}

	return 0;
}

/*
+=============================================================================+
| local functions
+=============================================================================+
*/

/*------------------------------------------------------------------------*//**
* \brief Initializes system
* \details Enables all GPIO ports
*//*-------------------------------------------------------------------------*/

static void system_init(void)
{
	ble_init();
}

/*
+=============================================================================+
| ISRs
+=============================================================================+
*
*/

/******************************************************************************
* END OF FILE
******************************************************************************/
